@@ -11,6 +11,7 @@ from .v3.domains import Domains
 from .v3.data_model import DataModel
 from .v3.device_monitoring import DeviceMonitoring
 from .v3.extensions import Extensions
+from .v3.groups import Groups
 from .v3.lifecycle_management import LifecycleManagement
 from .v3.resources import Resources
 from .v3.sessions import Sessions
@@ -53,6 +54,7 @@ class Coiote:
         self.dialects: Dialects = self._make_module(Dialects)
         self.domains: Domains = self._make_module(Domains)
         self.extensions: Extensions = self._make_module(Extensions)
+        self.groups: Groups = self._make_module(Groups)
         self.lifecycle_management: LifecycleManagement = self._make_module(LifecycleManagement)
         self.resources: Resources = self._make_module(Resources)
         self.sessions: Sessions = self._make_module(Sessions)
