@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 from datetime import datetime
-from typing import List
+from typing import List, Optional
 
 
 @dataclass
@@ -17,7 +17,7 @@ class TaskReport:
     startTime: datetime
     finishTime: datetime
     lastUpdateTime: datetime
-    summary: str
+    summary: Optional[str]
     blocking: bool
     properties: List[dict]
 
